### MK-Landscapes

This folder consists of the TD MK landscape benchmark problems, implemented based on the [problem generator](https://github.com/tobiasvandriessel/problem-generator).

The definition of the problem refers to 'Benchmark generator for TD Mk landscapes (GECCO'21)' ([https://dl.acm.org/doi/10.1145/3449726.3463177](https://dl.acm.org/doi/10.1145/3449726.3463177)) by Tobias van Driessel and Dirk Thierens. We appreciate Tobias' contribution to the implementation.

Due to the random generator, the implementation in this folder does not exactly match the results in the reference. The benchmark data of our implementation is under preparation.